@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ac-php-core" "2.7.0"
+(define-package "ac-php-core" "20260109.1426"
   "The core library of the ac-php."
   '((emacs    "24.4")
     (dash     "1")
@@ -9,8 +9,8 @@
     (popup    "0.5.0")
     (xcscope  "1.0"))
   :url "https://github.com/xcwen/ac-php"
-  :commit "a69ae4a12e40900619b4e5a1613fd449aef649c3"
-  :revdesc "a69ae4a12e40"
+  :commit "25a997da237ef87b561b037918cb372bce3b0665"
+  :revdesc "25a997da237e"
   :keywords '("completion" "convenience" "intellisense")
   :authors '(("jim" . "xcwenn@qq.com")
              ("Serghei Iakovlev" . "sadhooklay@gmail.com")))
